package myfitnessdiary.ui;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.time.LocalDate;
import java.util.Iterator;

import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JSpinner;
import javax.swing.JTextArea;
import javax.swing.SpinnerModel;
import javax.swing.SpinnerNumberModel;
import javax.swing.WindowConstants;

import myfitnessdiary.controller.Controller;
import myfitnessdiary.model.Activity;
import myfitnessdiary.model.Intensity;
import myfitnessdiary.model.Workout;

public class FitnessFrame extends JFrame implements ActionListener {

	private static final long serialVersionUID = 1L;

	private Controller controller;
	private JComboBox<String> activitiesComboBox;
	private JComboBox<Intensity> intensitiesComboBox;
	private MyDateSpinner dateSpinner;
	private JSpinner durationSpinner;
	private JTextArea dailyWorkout;
	private MyDateSpinner reportSpinner;

	public FitnessFrame(Controller myController) {
		this.controller = myController;
		initGui();
		bindData();
	}

	private void bindData() {
		Iterator<String> activ = controller.getActivities().iterator();
		while (activ.hasNext()) {
			activitiesComboBox.addItem(activ.next());
		}

		for (Intensity intensity : Intensity.values()) {
			intensitiesComboBox.addItem(intensity);
		}
	}

	private void initGui() {

		setTitle("My Fitness Diary");
		setDefaultCloseOperation(WindowConstants.EXIT_ON_CLOSE);
		getContentPane().setBackground(Color.WHITE);
		setLayout(new BorderLayout(5, 5));
		setSize(800, 480);
		JPanel leftPanel = new JPanel();
		{
			leftPanel.setLayout(new BoxLayout(leftPanel, BoxLayout.PAGE_AXIS));
			leftPanel.setBackground(Color.WHITE);
			// pannello inserimento workout
			JPanel upperLeftPanel = new JPanel();
			{
				upperLeftPanel.setLayout(new BorderLayout());

				// pannello lato sinistro
				JPanel insertLeft = new JPanel();
				{
					insertLeft.setLayout(new BoxLayout(insertLeft, BoxLayout.PAGE_AXIS));
					insertLeft.setBackground(Color.WHITE);
					// pannello data
					JPanel dateLeft = new JPanel();
					{
						dateLeft.setLayout(new BoxLayout(dateLeft, BoxLayout.PAGE_AXIS));
						dateLeft.setBackground(Color.WHITE);
						JLabel label = new JLabel("Data:");
						dateLeft.add(label);
						dateSpinner = new MyDateSpinner();
						dateLeft.add(dateSpinner);
					}
					insertLeft.add(dateLeft);

					// pannello attivit
					JPanel activitiesPanel = new JPanel();
					{
						activitiesPanel.setLayout(new BoxLayout(activitiesPanel, BoxLayout.PAGE_AXIS));
						activitiesPanel.setBackground(Color.WHITE);
						JLabel label = new JLabel("Attività:");
						activitiesPanel.add(label);
						activitiesComboBox = new JComboBox<String>();
						activitiesPanel.add(activitiesComboBox);
					}
					insertLeft.add(activitiesPanel);

				}

				upperLeftPanel.add(insertLeft, BorderLayout.WEST);

				// pannello lato destro
				JPanel insertRight = new JPanel();
				{
					insertRight.setLayout(new BoxLayout(insertRight, BoxLayout.PAGE_AXIS));
					insertRight.setBackground(Color.WHITE);
					// pannello durata
					JPanel durataRight = new JPanel();
					{
						durataRight.setLayout(new BoxLayout(durataRight, BoxLayout.PAGE_AXIS));
						durataRight.setBackground(Color.WHITE);
						JLabel label = new JLabel("Durata:");
						durataRight.add(label);
						SpinnerModel spinnerModel = new SpinnerNumberModel(0, 0, 1000, 5);
						durationSpinner = new JSpinner(spinnerModel);

						durataRight.add(durationSpinner);
					}

					insertRight.add(durataRight);

					// pannello intensità
					JPanel intensityPanel = new JPanel();
					{
						intensityPanel.setLayout(new BoxLayout(intensityPanel, BoxLayout.PAGE_AXIS));
						intensityPanel.setBackground(Color.WHITE);
						JLabel label = new JLabel("Intensità:");
						intensityPanel.add(label);
						intensitiesComboBox = new JComboBox<Intensity>();
						intensityPanel.add(intensitiesComboBox);
					}
					insertRight.add(intensityPanel);

				}

				upperLeftPanel.add(insertRight, BorderLayout.EAST);

				JPanel buttonPanel = new JPanel();
				buttonPanel.setLayout(new BorderLayout());
				buttonPanel.setBackground(Color.WHITE);
				JButton button = new JButton("Inserisci");
				button.addActionListener(this);
				button.setAlignmentX(RIGHT_ALIGNMENT);
				buttonPanel.add(button, BorderLayout.EAST);

				upperLeftPanel.add(buttonPanel, BorderLayout.SOUTH);

			}
			upperLeftPanel.setMaximumSize(new Dimension(Integer.MAX_VALUE, upperLeftPanel.getPreferredSize().width));
			leftPanel.add(upperLeftPanel);

			JPanel esportazionePanel = new JPanel();
			{
				esportazionePanel.setBackground(Color.WHITE);
				reportSpinner = new MyDateSpinner();

				JButton reportButton = new JButton("Stampa");
				reportButton.addActionListener(new ActionListener() {
					@Override
					public void actionPerformed(ActionEvent e) {
						controller.printWeekReport(reportSpinner.getDate());
					}
				});

				esportazionePanel.setLayout(new BoxLayout(esportazionePanel, BoxLayout.PAGE_AXIS));
				esportazionePanel.setBackground(Color.WHITE);
				esportazionePanel.add(new JLabel("Stampa report settimanale"));
				esportazionePanel.add(new JLabel("Seleziona Settimana:"));
				esportazionePanel.add(reportSpinner);
				esportazionePanel.add(reportButton);
				esportazionePanel
						.setMaximumSize(new Dimension(Integer.MAX_VALUE, esportazionePanel.getPreferredSize().width));
			}
			leftPanel.add(Box.createVerticalGlue());
			leftPanel.add(esportazionePanel);
			leftPanel.add(Box.createVerticalGlue());
		}

		getContentPane().add(leftPanel, BorderLayout.WEST);

		JScrollPane rightPanel = new JScrollPane();
		{
			dailyWorkout = new JTextArea();
			dailyWorkout.setEditable(false);
			rightPanel.setViewportView(dailyWorkout);
		}
		getContentPane().add(rightPanel, BorderLayout.CENTER);
	}

	@Override
	public void actionPerformed(ActionEvent e) {
		LocalDate date = dateSpinner.getDate();
		if (date == null) {
			JOptionPane.showMessageDialog(null, "La data inserita non  corretta");
			return;
		}
		int duration = (int) durationSpinner.getValue();
		if (duration <= 0) {
			JOptionPane.showMessageDialog(null, "Durata negativa non ammissibile");
			return;
		}
		Intensity intensity = (Intensity) intensitiesComboBox.getSelectedItem();
		if (intensity == null) {
			JOptionPane.showMessageDialog(null, "intensit negativa non ammissibile");
			return;
		}
		Activity activity = controller.getActivity((String) activitiesComboBox.getSelectedItem());
		if (activity == null) {
			JOptionPane.showMessageDialog(null, "Non esiste alcuna attivit con questo nome");
			return;
		}
		Workout wo = new Workout(date, duration, intensity, activity);
		controller.addWorkout(wo);
		dailyWorkout.setText(controller.getDayWorkout(LocalDate.now()));
	}

}
