package myfitnessdiary.model.test;

import static org.junit.Assert.*;

import java.time.LocalDate;

import org.junit.Before;
import org.junit.Test;

import myfitnessdiary.model.Activity;
import myfitnessdiary.model.Intensity;
import myfitnessdiary.model.Workout;

public class WorkoutTest {

	private Workout wo;
	private Activity act;

	@Before
	public void setUp() {
		act = new Activity("AS4");
		act.insertCalories(Intensity.LIGHT, 10);
		act.insertCalories(Intensity.MEDIUM, 11);
		act.insertCalories(Intensity.HIGH, 12);
	}

	@Test(expected = IllegalArgumentException.class)
	public void testBadParam1() {

		wo = new Workout(null, 20, Intensity.LIGHT, act);

	}

	@Test(expected = IllegalArgumentException.class)
	public void testBadParam2() {

		wo = new Workout(LocalDate.now(), -5, Intensity.LIGHT, act);

	}

	@Test(expected = IllegalArgumentException.class)
	public void testBadParam3() {
		Activity act = new Activity("AS4");
		act.insertCalories(Intensity.LIGHT, 10);
		act.insertCalories(Intensity.MEDIUM, 11);
		act.insertCalories(Intensity.HIGH, 12);
		wo = new Workout(LocalDate.now(), 20, null, act);

	}

	@Test(expected = IllegalArgumentException.class)
	public void testBadParam4() {
		Activity act = new Activity("AS4");
		act.insertCalories(Intensity.LIGHT, 10);
		act.insertCalories(Intensity.MEDIUM, 11);
		act.insertCalories(Intensity.HIGH, 12);
		wo = new Workout(LocalDate.now(), 20, Intensity.LIGHT, null);

	}

	@Test
	public void testgetDate() {
		wo = new Workout(LocalDate.now(), 20, Intensity.LIGHT, act);
		assertEquals(LocalDate.now(), wo.getDate());
	}

	@Test
	public void testgetDuration() {
		wo = new Workout(LocalDate.now(), 20, Intensity.LIGHT, act);
		assertEquals(20, wo.getDuration());
	}

	@Test
	public void testgetIntensity() {
		wo = new Workout(LocalDate.now(), 20, Intensity.LIGHT, act);
		assertEquals(Intensity.LIGHT, wo.getIntensity());
	}

	@Test
	public void testgetActivity() {
		wo = new Workout(LocalDate.now(), 20, Intensity.LIGHT, act);
		assertSame(act, wo.getActivity());
	}

	@Test
	public void testgetBurnedCalories() {
		wo = new Workout(LocalDate.now(), 20, Intensity.LIGHT, act);
		assertEquals(200, wo.getBurnedCalories());
	}

}
